@@ -280,5 +280,55 @@ class NavSoapClient():
                 siteType=site_type
         )
 
+        serialized_response = serialize_object(soap_response)
+        return serialized_response
+
+    def deploy_unit(self, cust_no, site_code, rental_order, unit_id, move_date, billing_start, engine_hours):
+        """
+        Use this when a unit is deployed to a site, to set the unit on the rental order.
+        """
+        session = Session()
+        session.auth = HTTPBasicAuth(self.nav_user, self.nav_password)
+
+        soap_service_url = self.nav_soap_service + \
+            self.nav_company + "/Codeunit/UnitMove"
+        client = Client(soap_service_url, transport=Transport(
+            session=session, cache=SqliteCache()))
+
+        soap_response = client.service.DeployEquip(
+            custNo = cust_no,
+            siteCode = site_code,
+            rentalOrderNo = rental_order,
+            equipNo = unit_id,
+            deployDate = move_date,
+            startDate = billing_start,
+            engineHours = engine_hours,
+        )
+
+        serialized_response = serialize_object(soap_response)
+        return serialized_response
+
+    def retrieve_unit(self, cust_no, site_code, rental_order, unit_id, move_date, billing_start, engine_hours):
+        """
+        Use this when a unit is retrieved from a site, to remove the unit from the rental order.
+        """
+        session = Session()
+        session.auth = HTTPBasicAuth(self.nav_user, self.nav_password)
+
+        soap_service_url = self.nav_soap_service + \
+            self.nav_company + "/Codeunit/UnitMove"
+        client = Client(soap_service_url, transport=Transport(
+            session=session, cache=SqliteCache()))
+
+        soap_response = client.service.ReturnEquip(
+            custNo = cust_no,
+            siteCode = site_code,
+            rentalOrderNo = rental_order,
+            equipNo = unit_id,
+            returnDate = move_date,
+            endDate = billing_start,
+            engineHours = engine_hours,
+        )
+
         serialized_response = serialize_object(soap_response)
         return serialized_response
\ No newline at end of file
